# scVAR

**scVAR** is a computational tool for extracting and integrating genetic variants from single-cell RNA-seq (scRNA-seq) data. It uses variational autoencoders to construct a latent space that combines transcriptional and genetic signals, helping to resolve cellular heterogeneity — particularly in complex diseases such as leukemia.

## 🔍 Motivation

Leukemias like AML and B-ALL exhibit high genetic and transcriptomic heterogeneity, making clonal analysis particularly challenging. Although scRNA-seq is widely used to study gene expression, it also contains valuable information on genetic variants. **scVAR** leverages this dual information to jointly analyze transcriptional and genetic signals from the same dataset, without requiring matched DNA sequencing.

## 🧠 What It Does

- Detects expressed genetic variants directly from scRNA-seq data  
- Integrates transcriptomic and variant information using multi-input variational autoencoders  
- Builds a shared latent space capturing both omics layers  
- Enhances detection of rare subclones and subtle transcriptional states  
- Recovers structure often missed when analyzing transcriptomic or genomic data in isolation

## 📊 Use Cases

- Clonal architecture analysis in AML and B-ALL  
- Interpretation of relapse samples  
- Joint modeling of gene expression and mutational signals  
- Effective utilization of sparse variant data from 10x Genomics 5′ scRNA-seq

## 📁 Data & Results

In AML samples, **scVAR** identified subclones with distinct transcriptional programs that were not detectable using gene expression or variant data alone. In B-ALL, it revealed fine-grained cellular structures and helped disentangle overlapping transcriptional and genetic signals.

## 🚀 Getting Started

An example of workflow is provided in the `example/` folder. A jupyter notebbok is also provided in the `notebooks/` folder.

## 🛠️ Installation

To install **scVAR**, create a new environment using `mamba` and install the package from source:

```
mamba create -n scvar_env python=3.10  
mamba activate scvar_env
git clone http://www.bioinfotiget.it/gitlab/custom/scvar.git
cd scvar  
pip install .
```

**Note:** scVAR requires **Python == 3.10**.

## 📜 License

Distributed under the MIT License. See the `LICENSE` file for more information.
